[svn-commits] russell: branch 1.8 r317867 - /branches/1.8/channels/chan_sip.c

SVN commits to the Digium repositories svn-commits at lists.digium.com
Fri May 6 15:01:22 CDT 2011


Author: russell
Date: Fri May  6 15:01:16 2011
New Revision: 317867

URL: http://svnview.digium.com/svn/asterisk?view=rev&rev=317867
Log:
chan_sip: Destroy variables on a sip_pvt before copying vars from the sip_peer.

Don't duplicate variables on the sip_pvt.  Just reset the variable list each
time.

(closes issue #19202)
Reported by: wdoekes
Patches:
      issue19202_destroy_challenged_invite_chanvars.patch uploaded by wdoekes (license 717)

Modified:
    branches/1.8/channels/chan_sip.c

Modified: branches/1.8/channels/chan_sip.c
URL: http://svnview.digium.com/svn/asterisk/branches/1.8/channels/chan_sip.c?view=diff&rev=317867&r1=317866&r2=317867
==============================================================================
--- branches/1.8/channels/chan_sip.c (original)
+++ branches/1.8/channels/chan_sip.c Fri May  6 15:01:16 2011
@@ -15324,7 +15324,8 @@
 		ast_string_field_set(p, authname, peer->name);
 
 		if (sipmethod == SIP_INVITE) {
-			/* copy channel vars */
+			/* destroy old channel vars and copy in new ones. */
+			ast_variables_destroy(p->chanvars);
 			p->chanvars = copy_vars(peer->chanvars);
 		}
 




More information about the svn-commits mailing list